@@ -1,13 +1,15 @@
+use 5.006;
+use strict;
+use warnings;
 package Email::Simple;
 
-use 5.00503; # why? -- rjbs, 2007-04-01
-use strict;
 use Carp ();
 
+use Email::Simple::Creator;
 use Email::Simple::Header;
 
-$Email::Simple::VERSION = '2.004';
-$Email::Simple::GROUCHY = 0;
+our $VERSION = '2.100';
+our $GROUCHY = 0;
 
 # We are liberal in what we accept.
 sub __crlf_re { qr/\x0a\x0d|\x0d\x0a|\x0a|\x0d/; }
@@ -30,6 +32,21 @@ Email::Simple - simple parsing of RFC2822 message format and headers
 
   print $email->as_string;
 
+...or, to create a message from scratch...
+  
+  my $email = Email::Simple->create(
+      header => [
+        From    => 'casey@geeknest.com',
+        To      => 'drain@example.com',
+        Subject => 'Message in a bottle',
+      ],
+      body => '...',
+  );
+  
+  $email->header_set( 'X-Content-Container' => 'bottle/glass' );
+  
+  print $email->as_string;
+
 =head1 DESCRIPTION
 
 C<Email::Simple> is the first deliverable of the "Perl Email Project."  The
@@ -109,6 +126,58 @@ sub _split_head_from_body {
   }
 }
 
+=head2 create
+
+  my $email = Email::Simple->create(header => [ @headers ], body => '...');
+
+This method is a constructor that creates an Email::Simple object
+from a set of named parameters. The C<header> parameter's value is a
+list reference containing a set of headers to be created. The C<body>
+parameter's value is a scalar value holding the contents of the message
+body.  Line endings in the body will normalized to CRLF.
+
+If no C<Date> header is specified, one will be provided for you based on the
+C<gmtime> of the local machine. This is because the C<Date> field is a required
+header and is a pain in the neck to create manually for every message. The
+C<From> field is also a required header, but it is I<not> provided for you.
+
+=cut
+
+our $CREATOR = 'Email::Simple::Creator';
+
+sub create {
+  my ($class, %args) = @_;
+
+  # We default it in here as well as below because by having it here, then we
+  # know that if there are no other headers, we'll get the proper CRLF.
+  # Otherwise, we get a message with incorrect CRLF. -- rjbs, 2007-07-13
+  my $headers = $args{header} || [ Date => $CREATOR->_date_header ];
+  my $body    = $args{body} || '';
+
+  my $empty   = q{};
+  my $header  = \$empty;
+
+  for my $idx (map { $_ * 2 } 0 .. @$headers / 2 - 1) {
+    my ($key, $value) = @$headers[ $idx, $idx + 1 ];
+    $CREATOR->_add_to_header($header, $key, $value);
+  }
+
+  $CREATOR->_finalize_header($header);
+
+  my $email = $class->new($header);
+
+  $email->header_set(Date => $CREATOR->_date_header)
+    unless defined $email->header('Date');
+
+  $body = (join $CREATOR->_crlf, split /\x0d\x0a|\x0a\x0d|\x0a|\x0d/, $body)
+        . $CREATOR->_crlf;
+
+  $email->body_set($body);
+
+  return $email;
+}
+
+
 =head2 header_obj
 
   my $header = $email->header_obj;
@@ -155,7 +224,8 @@ context, it returns the I<first> value for the named header.
     $email->header_set($field, $line1, $line2, ...);
 
 Sets the header to contain the given data. If you pass multiple lines
-in, you get multiple headers, and order is retained.
+in, you get multiple headers, and order is retained.  If no values are given to
+set, the header will be removed from to the message entirely.
 
 =head2 header_names
 
